@@ -44,7 +44,6 @@ fn main() {
 }
 ```
 */
-#![feature(test)]
 
 #[cfg(feature = "bench")]
 extern crate test;
@@ -112,24 +111,27 @@ lazy_static! {
     // （）【】「」《》
     static ref LEFT_QUOTE_RE: Regex = regexp!("{}", r" ([（【「《])");
     static ref RIGHT_QUOTE_RE: Regex = regexp!("{}", r"([）】」》]) ");
+
     // Strategies all rules
     static ref STRATEGIES: Vec<Strategery> = vec![
         // EnglishLetter, Number
-        // But not start with %, $, \ for avoid change %s, %d, $1, $2, \d, \r, \p ... in source code
-        Strategery::new(r"\p{CJK}[^%\$\\]", r"[a-zA-Z0-9]", true, false),
-        Strategery::new(r"[^%\$\\][a-zA-Z0-9]", r"\p{CJK}", true, false),
+        // Avoid add space when Letter, Number has %, $, \ prefix, eg. %s, %d, $1, $2, \1, \2, \d, \r, \p ... in source code
+        Strategery::new(r"\p{CJK}[^%\$\\]", r"[a-zA-Z0-9]"),
+        Strategery::new(r"[^%\$\\][a-zA-Z0-9]", r"\p{CJK}"),
+        // Spcial format Letter, Number leading case, because the before Strategery can't cover eg. A开头的case测试
+        Strategery::new(r"^[a-zA-Z0-9]", r"\p{CJK}"),
         // 10%中文
-        Strategery::new(r"[0-9][%]", r"\p{CJK}", true, false),
+        Strategery::new(r"[0-9][%]", r"\p{CJK}"),
         // SpecialSymbol
-        Strategery::new(r"\p{CJK}", r"[\|+]", true, true),
+        Strategery::new(r"\p{CJK}", r"[\|+]").with_reverse(),
         // @ after CJK, not not before, 你好 @某某
-        Strategery::new(r"\p{CJK}", r"[@]", true, false),
-        Strategery::new(r"\p{CJK}", r"[\[\(]", true, false),
-        Strategery::new(r"[\]\)!]", r"\p{CJK}", true, false),
+        Strategery::new(r"\p{CJK}", r"[@]"),
+        Strategery::new(r"\p{CJK}", r"[\[\(]"),
+        Strategery::new(r"[\]\)!]", r"\p{CJK}"),
 
         // FullwidthPunctuation remove space case, Fullwidth can safe to remove spaces
-        Strategery::new(r"[\w\p{CJK}]", r"[，。！？：；）」》】”’]", false, true),
-        Strategery::new(r"[‘“【「《（]", r"[\w\p{CJK}]", false, true),
+        Strategery::new(r"[\w\p{CJK}]", r"[，。！？：；）」》】”’]").with_remove_space().with_reverse(),
+        Strategery::new(r"[‘“【「《（]", r"[\w\p{CJK}]").with_remove_space().with_reverse(),
     ];
 }
 
@@ -283,6 +285,7 @@ mod tests {
     #[test]
     fn it_format_for_programming() {
         let cases = map![
+            "A开头的case测试" => "A 开头的 case 测试",
             "内容带有\n不会处理" => "内容带有\n不会处理",
             "内容带有%s或%d或%v特殊字符，或者%S或%D或%V这些特殊format字符" => "内容带有%s或%d或%v特殊字符，或者%S或%D或%V这些特殊 format 字符",
             "内容带有$1或$2或$3特殊字符" => "内容带有$1或$2或$3特殊字符"
